# Awesome tool for working on KMM projects

## Features

1. Creating new project with template
2. Fast rename shared module
3. Fast rename package
4. Generating components (Decompose)
5. Generating empty features (components, data layer, domain entities)
